#[non_exhaustive]pub struct SessionConfiguration {
pub reasoning: Option<ReasoningConfiguration>,
pub peer_card: Option<PeerCardConfiguration>,
pub summary: Option<SummaryConfiguration>,
pub dream: Option<DreamConfiguration>,
}Expand description
Session-level configuration overrides.
All fields are optional. Session-level configuration overrides workspace-level configuration, which overrides global configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reasoning: Option<ReasoningConfiguration>Configuration for reasoning functionality.
peer_card: Option<PeerCardConfiguration>Configuration for peer card functionality.
If reasoning is disabled, peer cards will also be disabled and these settings will be ignored.
summary: Option<SummaryConfiguration>Configuration for summary functionality.
dream: Option<DreamConfiguration>Configuration for dream functionality.
If reasoning is disabled, dreams will also be disabled and these settings will be ignored.